Reason

Struct Reason 

pub struct Reason(/* private fields */);
HTTP/2 error codes.

Error codes are used in RST_STREAM and GOAWAY frames to convey the reasons for the stream or connection error. For example, SendStream::send_reset takes a Reason argument. Also, the Error type may contain a Reason.

Error codes share a common code space. Some error codes apply only to streams, others apply only to connections, and others may apply to either. See [RFC 7540] for more information.

See Error Codes in the spec.

Implementations

Source

impl Reason

pub const NO_ERROR: Reason

The associated condition is not a result of an error.

For example, a GOAWAY might include this code to indicate graceful shutdown of a connection.

pub const PROTOCOL_ERROR: Reason

The endpoint detected an unspecific protocol error.

This error is for use when a more specific error code is not available.

pub const INTERNAL_ERROR: Reason

The endpoint encountered an unexpected internal error.

pub const FLOW_CONTROL_ERROR: Reason

The endpoint detected that its peer violated the flow-control protocol.

pub const SETTINGS_TIMEOUT: Reason

The endpoint sent a SETTINGS frame but did not receive a response in a timely manner.

pub const STREAM_CLOSED: Reason

The endpoint received a frame after a stream was half-closed.

pub const FRAME_SIZE_ERROR: Reason

The endpoint received a frame with an invalid size.

pub const REFUSED_STREAM: Reason

The endpoint refused the stream prior to performing any application processing.

pub const CANCEL: Reason

Used by the endpoint to indicate that the stream is no longer needed.

pub const COMPRESSION_ERROR: Reason

The endpoint is unable to maintain the header compression context for the connection.

pub const CONNECT_ERROR: Reason

The connection established in response to a CONNECT request was reset or abnormally closed.

pub const ENHANCE_YOUR_CALM: Reason

The endpoint detected that its peer is exhibiting a behavior that might be generating excessive load.

pub const INADEQUATE_SECURITY: Reason

The underlying transport has properties that do not meet minimum security requirements.

pub const HTTP_1_1_REQUIRED: Reason

The endpoint requires that HTTP/1.1 be used instead of HTTP/2.

pub fn description(&self) -> &str

Get a string description of the error code.